import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.Calendar;

public class Clock
{  
    public static void main(String[] args) 
    {
	SwingApp app = new SwingApp(220, 250);	    // set app window size
	app.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE); 
    }
}

class SwingApp extends JFrame implements ActionListener
{
    private final DrawPanel panel;		    // class variable
    
    public SwingApp(int width, int height)	    // class constructor
    {
	super();				    // call to super class constructor
	Container pane = super.getContentPane();    // create layout, set colors
	panel = new DrawPanel();		    // add GUI components
	panel.setBackground(new Color(0xFFA766));
        // add other GUI components to the panel
        Calendar cal = Calendar.getInstance();
        panel.hours = cal.get(Calendar.HOUR);
        panel.minutes =  cal.get(Calendar.MINUTE);
        panel.seconds = cal.get(Calendar.SECOND);

	pane.add(panel);                            // add panel to the main app container
	Toolkit toolkit = Toolkit.getDefaultToolkit();	// optionally position JFrame
	Dimension screenSize = toolkit.getScreenSize(); // in the middle of the screen 
	super.setLocation((screenSize.width - width)/2, (screenSize.height - height)/2);	
	super.setTitle("Swing app");		    // set desired window title
	super.setSize(width, height);		    // set desired window size
	super.setVisible(true);	                    // make the app window visible
        
        Timer timer = new Timer(1000, this);
        timer.start();
    }
    
    public void actionPerformed(ActionEvent e)
    {
        panel.updateTime();
        panel.repaint();
    }  
}

class DrawPanel extends JPanel			    // main window panel
{
    public int seconds, minutes, hours;
       
    public void updateTime()
    {
        seconds++;
        if (seconds == 60)
        {
            seconds = 0;
            minutes++;
            if (minutes == 60)
            {
                hours++;
                if (hours == 12)
                    hours = 0;
            }
        }        
    }
    
    @Override
    public void paintComponent(Graphics g)
    {
	super.paintComponent(g);		    // must be the 1st line
	// add here other code for drawing on panel 
        g.setColor(Color.BLACK);
        g.drawOval(99, 99, 3, 3);                   // draw the nail
        g.drawOval(5, 5, 190, 190);                 // draw the clock circle
        
        int rClock = 95;                  // clock radius  
        int rNumbers = 80;                // number radius 
        int rHourHand = 50;               // hours hand length 
        int rMinHand = 70;                // minutes hand length
        int rSecHand = 80;                // seconds hand length        
        
        int width1 = g.getFontMetrics().stringWidth("0");
        int width2 = g.getFontMetrics().stringWidth("00");
        int height = g.getFontMetrics().getHeight(); 
        
        g.setColor(Color.magenta); 
        g.drawString("12", (int)(100 - width2/2.0), 
	   (int)(100 - rNumbers + height/2.0));
        g.drawString("6",  (int)(100 - width1/2.0), 
	   (int)(100 + rNumbers + height/2.0 - 5));
        g.drawString("9",  (int)(100 - rNumbers - width1/2.0), 
	   (int)(100 + height/2.0 - 2));
        g.drawString("3",  (int)(100 + rNumbers - width1/2.0), 
	   (int)(100 + height/2.0 - 2));
        
        g.setColor(Color.green);
        double angle = (90 - seconds*6.0)*Math.PI/180;
        g.drawLine(100, 100, (int)(100 + rSecHand*Math.cos(angle)),
	     (int)(100 - rSecHand*Math.sin(angle)));
        
        g.setColor(Color.red);
        angle = (90 - minutes*6.0)*Math.PI/180;
        g.drawLine(100, 100, (int)(100 + rMinHand*Math.cos(angle)), 
	     (int)(100 - rMinHand*Math.sin(angle)));

        g.setColor(Color.blue);
        angle = (90 - (hours + minutes/60.0)*30.0)*Math.PI/180;
        g.drawLine(100, 100, (int)(100 + rHourHand*Math.cos(angle)),    
                           (int)(100 - rHourHand*Math.sin(angle)));
        
        g.setColor(Color.BLACK);
        for (int i=0; i<60; i++)                // draw seconts ticks
        {
            angle = i*6*Math.PI/180;
            g.drawLine(100 + (int)(90*Math.cos(angle)), 
                       100 - (int)(90*Math.sin(angle)),
                       100 + (int)(95*Math.cos(angle)), 
                       100 - (int)(95*Math.sin(angle)));
        }
        
        for (int i=0; i<12; i++)                // draw minutes ticks
        {
            angle = i*30*Math.PI/180;
            g.drawLine(100 + (int)(85*Math.cos(angle)), 
                       100 - (int)(85*Math.sin(angle)),
                       100 + (int)(95*Math.cos(angle)), 
                       100 - (int)(95*Math.sin(angle)));
        }
    }
}  

